FontTech

Enum FontTech 

pub enum FontTech {
    ColorCbdt,
    ColorColrV0,
    ColorColrV1,
    ColorSbix,
    ColorSvg,
    FeaturesAat,
    FeaturesGraphite,
    FeaturesOpenType,
    Incremental,
    Palettes,
    Variations,
}
A font technology, as named by the tech() hint of a CSS @font-face src descriptor.

Displays as the CSS technology keyword used inside tech(...) (color-colrv1, features-opentype, variations, …).

Variants



ColorCbdt

Color bitmap data tables, CSS color-cbdt.



ColorColrV0

Multi-colored glyphs via COLR version 0 table, CSS color-colrv0.



ColorColrV1

Multi-colored glyphs via COLR version 1 table, CSS color-colrv1.



ColorSbix

Standard bitmap graphics tables, CSS color-sbix.



ColorSvg

SVG multi-colored tables, CSS color-svg.



FeaturesAat

TrueType morx and kerx tables, CSS features-aat.



FeaturesGraphite

Graphite features, namely Silf, Glat, Gloc, Feat, and Sill tables, CSS features-graphite.



FeaturesOpenType

OpenType GSUB and GPOS tables, CSS features-opentype.



Incremental

Incremental font loading, CSS incremental.



Palettes

Font palettes by means of font-palette to select one of many color palettes in the font, CSS palettes.



Variations

Font variations in TrueType and OpenType fonts to control the font axis, weight, glyphs, etc., CSS variations.

Implementations

Source

impl FontTech

pub const fn keyword(self) -> &'static str

The CSS technology keyword for this technology, as written inside tech(...).

pub fn from_keyword(keyword: &str) -> Option<Self>

The technology named by the given CSS tech(...) keyword, if the keyword names a known technology.