pub struct FontResolver { /* private fields */ }Expand description
Function registered with the app context that resolves a Font to its
hosted stylesheet URL.
Registered by RouterBuilderFontExt
when a font is added to the router, and read when a Font is used as an
attribute value in the view! macro.
Implementations
Sourceimpl FontResolver
impl FontResolver