PreloadLinkPropsBuilder

Struct PreloadLinkPropsBuilder 

pub struct PreloadLinkPropsBuilder<'__a, __source = source> { /* private fields */ }
Available on crate feature view only.
Typestate builder for PreloadLinkProps, created by PreloadLinkProps::builder(). build() becomes available once every required property has been set.

Implementations

Source

impl<'__a, __source> PreloadLinkPropsBuilder<'__a, __source>

pub fn source( self, source: &'__a FontSource, ) -> PreloadLinkPropsBuilder<'__a, Set>

The font source to preload.

pub fn build(self) -> PreloadLinkProps<'__a>
where __source: IsSet,

Builds the props struct from the set properties.

Only available once every required property has been set. #[default] properties that were not set are filled with Default::default(), or the #[default(expr)] expression.